@@ -2,6 +2,11 @@
 
 import cell_machine_levels
 
+get_level_code = lambda: input("Input level code (V1, V2 or V3): ")
+get_level = lambda: cell_machine_levels.level.open(get_level_code())
+
+get_format = lambda: input("Format to output in (V1, V2 or V3): ")
+
 choices = [
     [
         [
@@ -32,24 +37,24 @@ choices = [
     [
         [
             lambda: 0,
+            lambda: print(get_level().optimized().save(get_format())) or 2,
             lambda: print(
-                cell_machine_levels.level.open(
-                    input("Input level code (V1, V2 or V3): ")
+                get_level()
+                .resized(
+                    int(input("Add to cells the left: ")),
+                    int(input("Add to cells the right: ")),
+                    int(input("Add to cells the top: ")),
+                    int(input("Add to cells the bottom: ")),
                 )
-                .optimized()
-                .save(input("Format to output in (V1, V2 or V3): "))
-            )
-            or 2,
-            lambda: print(
-                cell_machine_levels.level.open(
-                    input("Input level code (V1, V2 or V3): ")
-                ).save(input("Format to output in (V1, V2 or V3): "))
+                .save(get_format())
             )
             or 2,
+            lambda: print(get_level().save(get_format())) or 2,
         ],
         [
             "Go Back",
             "Optimize Level (only good for V2 and V3)",
+            "Resize Level",
             "Convert Level To Other Format",
         ],
     ],
